#!/usr/bin/env python3

import boto3
import re
import requests
import subprocess

# Configuration variables
AWS_ACCESS_KEY = ''
AWS_SECRET_KEY = ''

HOSTED_ZONE_ID = ''
HOSTED_ZONE_FQDN = ''

INTERFACE_NAME = 'en0'
IPV = 4


r53 = boto3.client('route53',
                   aws_access_key_id=AWS_ACCESS_KEY,
                   aws_secret_access_key=AWS_SECRET_KEY)


# Get the ifconfig entry for the specified interface.
ifconfig = subprocess.run(["ifconfig", INTERFACE_NAME], stdout=subprocess.PIPE)

# Determine the IP address by regex.
if IPV == 4:
    re_pre = ".*inet"
    re_match = "(\d{1,3}\.){3}\d{1,3}"
    re_post = "netmask.*"

    regex = re.search("%s (%s) %s" % (re_pre, re_match, re_post), ifconfig.stdout.decode())

elif IPV == 6:
    re_pre = ".*inet6"
    re_match = "(\w{1,4}:{1,2}){1,7}\w{1,4}"

    regex = re.search("%s (%s)" % (re_pre, re_match), ifconfig.stdout.decode())

else:
    print("Invalid IP version")
    exit()

# Save the IP address.
ip_address = regex.groups()[0]

CHANGE_BATCH_TEMPLATE = {
    'Changes': [{
        'Action': 'UPSERT',
        'ResourceRecordSet': {
            'Name': HOSTED_ZONE_FQDN,
            'Type': 'A',
            'TTL': 60,
            'ResourceRecords': [{'Value': ip_address}]
        },

    }],
    'Comment': 'Dynamic DNS update.'
}

# Submit the request.
r53.change_resource_record_sets(ChangeBatch=CHANGE_BATCH_TEMPLATE, HostedZoneId=HOSTED_ZONE_ID)
